==> brmo-stufbg204-1.5.0-sources.jar: nl/egem/stuf/sector/bg/_0204/PRSADRVBL.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRSADRVBL complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRSADRVBL">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens">
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRSADRVBL")
public class PRSADRVBL
    extends ADRRelKerngegevens
{

    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/PRSADRVBL.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRSADRVBL complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRSADRVBL"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens"&gt;
 *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRSADRVBL")
public class PRSADRVBL
    extends ADRRelKerngegevens
{

    @XmlAttribute(name = "kerngegeven")
    protected Boolean kerngegeven;

    /**
     * Gets the value of the kerngegeven property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isKerngegeven() {
        if (kerngegeven == null) {
            return true;
        } else {
            return kerngegeven;
        }
    }

    /**
     * Sets the value of the kerngegeven property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setKerngegeven(Boolean value) {
        this.kerngegeven = value;
    }

}
